@@ -2,14 +2,17 @@ from __future__ import annotations
 
 import json
 import typing as t
+from collections import defaultdict
 
 import click
 import globus_sdk
 
 from globus_cli import termio, version
 from globus_cli.login_manager import LoginManager
+from globus_cli.login_manager.scopes import CLI_SCOPE_REQUIREMENTS
 from globus_cli.parsing import command, group, mutex_option_group
 from globus_cli.termio import display
+from globus_cli.types import ServiceNameLiteral
 
 
 class QueryParamType(click.ParamType):
@@ -109,16 +112,6 @@ def print_error_or_response(
         display(data, simple_text=data.text)
 
 
-_SERVICE_MAP = {
-    "auth": LoginManager.AUTH_RS,
-    "flows": LoginManager.FLOWS_RS,
-    "groups": LoginManager.GROUPS_RS,
-    "search": LoginManager.SEARCH_RS,
-    "transfer": LoginManager.TRANSFER_RS,
-    "timer": LoginManager.TIMER_RS,
-}
-
-
 def _get_client(
     login_manager: LoginManager, service_name: str
 ) -> globus_sdk.BaseClient:
@@ -156,7 +149,7 @@ def api_command() -> None:
 
 # note: this must be written as a separate call and not inlined into the loop body
 # this ensures that it acts as a closure over 'service_name'
-def build_command(service_name: str) -> click.Command:
+def build_command(service_name: ServiceNameLiteral) -> click.Command:
     @command(
         service_name,
         help=f"""\
@@ -171,7 +164,7 @@ For example, a call of
 sends a 'GET' request to '{_get_url(service_name)}foo/bar'
 """,
     )
-    @LoginManager.requires_login(_SERVICE_MAP[service_name])
+    @LoginManager.requires_login(service_name)
     @click.argument(
         "method",
         type=click.Choice(
@@ -254,9 +247,9 @@ sends a 'GET' request to '{_get_url(service_name)}foo/bar'
             client.transport.max_retries = 0
 
         # Prepare Query Params
-        query_params_d = {}
+        query_params_d = defaultdict(list)
         for param_name, param_value in query_param:
-            query_params_d[param_name] = param_value
+            query_params_d[param_name].append(param_value)
 
         # Prepare Request Body
         # the value in 'body' will be passed in the request
@@ -306,5 +299,5 @@ sends a 'GET' request to '{_get_url(service_name)}foo/bar'
     return t.cast(click.Command, service_command)
 
 
-for service_name in _SERVICE_MAP:
+for service_name in CLI_SCOPE_REQUIREMENTS:
     api_command.add_command(build_command(service_name))
