@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Any, Dict, cast
+import typing as t
 from uuid import UUID
 
 import click
@@ -9,7 +9,7 @@ import globus_sdk
 
 def resolve_id_or_name(
     client: globus_sdk.TransferClient, bookmark_id_or_name: str
-) -> globus_sdk.GlobusHTTPResponse | dict[str, Any]:
+) -> globus_sdk.GlobusHTTPResponse | dict[str, t.Any]:
     # leading/trailing whitespace doesn't make sense for UUIDs and the Transfer
     # service outright forbids it for bookmark names, so we can strip it off
     bookmark_id_or_name = bookmark_id_or_name.strip()
@@ -32,8 +32,8 @@ def resolve_id_or_name(
     try:
         # n.b. case matters to the Transfer service for bookmark names, so
         # two bookmarks can exist whose names vary only by their case
-        return cast(
-            Dict[str, Any],
+        return t.cast(
+            t.Dict[str, t.Any],
             next(
                 bookmark_row
                 for bookmark_row in client.bookmark_list()
