@@ -47,7 +47,7 @@ $ globus bookmark list --jmespath='DATA[*].[name, endpoint_id]' --format=unix
 """,
     short_help="List your bookmarks",
 )
-@LoginManager.requires_login(LoginManager.TRANSFER_RS)
+@LoginManager.requires_login("transfer")
 def bookmark_list(*, login_manager: LoginManager) -> None:
     """List all bookmarks for the current user"""
     from globus_cli.services.transfer import iterable_response_to_dict
