@@ -5,7 +5,7 @@ from globus_cli.termio import TextMode, display
 
 @command("delete", short_help="Delete an existing Collection")
 @collection_id_arg
-@LoginManager.requires_login(LoginManager.TRANSFER_RS)
+@LoginManager.requires_login("transfer")
 def collection_delete(*, login_manager: LoginManager, collection_id):
     """
     Delete an existing Collection. This requires the administrator role on the
