@@ -9,7 +9,7 @@ from globus_cli.termio import Field, TextMode, display, formatters
 
 @command("delete", short_help="Delete a flow")
 @flow_id_arg
-@LoginManager.requires_login(LoginManager.FLOWS_RS)
+@LoginManager.requires_login("flows")
 def delete_command(login_manager: LoginManager, flow_id: uuid.UUID):
     """
     Delete a flow
