@@ -10,7 +10,7 @@ from ._common import group_create_and_update_params, group_id_arg
 @group_create_and_update_params()
 @group_id_arg
 @command("update")
-@LoginManager.requires_login(LoginManager.GROUPS_RS)
+@LoginManager.requires_login("groups")
 def group_update(*, login_manager: LoginManager, group_id: str, **kwargs: t.Any):
     """Update an existing group."""
     groups_client = login_manager.get_groups_client()
