@@ -10,7 +10,7 @@ INDEX_LIST_FIELDS = INDEX_FIELDS + [
 
 
 @command("list")
-@LoginManager.requires_login(LoginManager.SEARCH_RS)
+@LoginManager.requires_login("search")
 def list_command(*, login_manager: LoginManager):
     """List indices where you have some permissions"""
     search_client = login_manager.get_search_client()
