@@ -16,7 +16,7 @@ TASK_FIELDS = [
 
 @command("list", short_help="List recent Tasks for an index")
 @index_id_arg
-@LoginManager.requires_login(LoginManager.SEARCH_RS)
+@LoginManager.requires_login("search")
 def list_command(*, login_manager: LoginManager, index_id: uuid.UUID):
     """List the 1000 most recent Tasks for an index"""
     search_client = login_manager.get_search_client()
