@@ -64,13 +64,13 @@ $ globus task pause-info TASK_ID --format JSON
 ----
 """,
 )
-@task_id_arg
+@task_id_arg()
 @click.option(
     "--limit", type=int, default=10, show_default=True, help="Limit number of results."
 )
 @click.option("--filter-errors", is_flag=True, help="Filter results to errors")
 @click.option("--filter-non-errors", is_flag=True, help="Filter results to non errors")
-@LoginManager.requires_login(LoginManager.TRANSFER_RS)
+@LoginManager.requires_login("transfer")
 def task_event_list(
     *,
     login_manager: LoginManager,
@@ -78,7 +78,7 @@ def task_event_list(
     limit: int,
     filter_errors: bool,
     filter_non_errors: bool,
-):
+) -> None:
     """
     This command shows the recent events for a running task.
     Most events of interest are fault events, which are errors which occurred on an
