@@ -39,6 +39,8 @@ def session_hook(exception: globus_sdk.GlobusAPIError) -> None:
 
     identities = exception.info.authorization_parameters.session_required_identities
     domains = exception.info.authorization_parameters.session_required_single_domain
+    policies = exception.info.authorization_parameters.session_required_policies
+
     if identities or domains:
         # cast: mypy can't deduce that `domains` is not None if `identities` is None
         update_target = (
@@ -51,6 +53,12 @@ def session_hook(exception: globus_sdk.GlobusAPIError) -> None:
             f"    globus session update {update_target}\n\n"
             "to re-authenticate with the required identities"
         )
+    elif policies:
+        click.echo(
+            "Please run\n\n"
+            f"    globus session update --policy '{','.join(policies)}'\n\n"
+            "to re-authenticate with the required identities"
+        )
     else:
         click.echo(
             'Please use "globus session update" to re-authenticate '
