@@ -1,10 +1,14 @@
 from .client_login import get_client_login, is_client_login
 from .errors import MissingLoginError
 from .manager import LoginManager
+from .scopes import compute_timer_scope
 from .tokenstore import (
     delete_templated_client,
     internal_auth_client,
     internal_native_client,
+    read_well_known_config,
+    remove_well_known_config,
+    store_well_known_config,
     token_storage_adapter,
 )
 from .utils import is_remote_session
@@ -19,4 +23,8 @@ __all__ = [
     "token_storage_adapter",
     "is_client_login",
     "get_client_login",
+    "store_well_known_config",
+    "read_well_known_config",
+    "remove_well_known_config",
+    "compute_timer_scope",
 ]
