@@ -1,13 +1,21 @@
+import typing as t
+
 from globus_cli import utils
 
+from .scopes import CLI_SCOPE_REQUIREMENTS
+
 
 class MissingLoginError(ValueError):
-    def __init__(self, missing_servers, *, assume_gcs=False, assume_flow=False):
+    def __init__(
+        self, missing_servers: t.Sequence[str], *, assume_gcs=False, assume_flow=False
+    ):
         self.missing_servers = missing_servers
         self.assume_gcs = assume_gcs
         self.assume_flow = assume_flow
 
-        server_string = utils.format_list_of_words(*missing_servers)
+        self.server_names = sorted(_resolve_server_names(missing_servers))
+
+        server_string = utils.format_list_of_words(*self.server_names)
         message_prefix = utils.format_plural_str(
             "Missing {login}",
             {"login": "logins"},
@@ -25,9 +33,18 @@ class MissingLoginError(ValueError):
             )
 
         self.message = (
-            message_prefix + f" for {server_string}, please run\n\n  {login_cmd}\n"
+            message_prefix + f" for {server_string}, please run:\n\n  {login_cmd}\n"
         )
         super().__init__(self.message)
 
     def __str__(self):
         return self.message
+
+
+def _resolve_server_names(server_names: t.Sequence[str]) -> t.Iterator[str]:
+    for name in server_names:
+        try:
+            req = CLI_SCOPE_REQUIREMENTS.get_by_resource_server(name)
+            yield req["nice_server_name"]
+        except LookupError:
+            yield name
