@@ -1,7 +1,11 @@
 from __future__ import annotations
 
+import typing as t
+
 import globus_sdk
 
+from globus_cli.termio import formatters
+
 CONNECTOR_INFO: list[dict[str, str]] = [
     {
         "connector_id": "145812c8-decc-41f1-83cf-bb2a85a2a70b",
@@ -72,6 +76,13 @@ def connector_id_to_display_name(connector_id: str) -> str:
     return display_name
 
 
+class ConnectorIdFormatter(formatters.StrFormatter):
+    def parse(self, value: t.Any) -> str:
+        if not isinstance(value, str):
+            raise ValueError("bad connector ID")
+        return connector_id_to_display_name(value)
+
+
 class CustomGCSClient(globus_sdk.GCSClient):
     def __init__(self, *args, source_epish=None, **kwargs):
         super().__init__(*args, **kwargs)
